@@ -2,10 +2,11 @@ import doctest
 import unittest
 
 
-docfiles = ('shorturl.txt', 'django.txt')
+docfiles = ('shorturl.rst', 'django.rst', 'appengine.rst')
 
 docstrings = ('ao.shorturl',)
 
+
 def test_suite():
     """Run all doctests in one test suite."""
 
